AtlasCommand

Enum AtlasCommand 

pub enum AtlasCommand {
    SetTransform(Affine),
    SetPaint(AtlasPaint),
    SetPaintTransform(Affine),
    FillPath(Arc<BezPath>),
    FillRect(Rect),
    PushClipLayer(Arc<BezPath>),
    PushClipPath(Arc<BezPath>),
    PushBlendLayer(BlendMode),
    PopLayer,
    PopClipPath,
}
A single draw command recorded for deferred atlas rendering.

The variants correspond 1:1 to the methods on DrawSink.

Variants



SetTransform(Affine)

Set the current transform.



SetPaint(AtlasPaint)

Set the current paint (solid colour or gradient).



SetPaintTransform(Affine)

Set the paint transform.



FillPath(Arc<BezPath>)

Fill a path with the current paint and transform.



FillRect(Rect)

Fill a rectangle with the current paint and transform.



PushClipLayer(Arc<BezPath>)

Push a clip layer defined by a path.



PushClipPath(Arc<BezPath>)

Push a clip path.



PushBlendLayer(BlendMode)

Push a blend/compositing layer.



PopLayer

Pop the most recent clip or blend layer.



PopClipPath

Pop the most recent clip path.